@@ -15,10 +15,8 @@
 from typing import Iterator
 
 from eva.executor.abstract_executor import AbstractExecutor
-from eva.executor.executor_utils import ExecutorError
 from eva.models.storage.batch import Batch
 from eva.plan_nodes.hash_join_build_plan import HashJoinBuildPlan
-from eva.utils.logging_manager import logger
 
 
 class BuildJoinExecutor(AbstractExecutor):
@@ -28,22 +26,13 @@ class BuildJoinExecutor(AbstractExecutor):
         self.join_type = node.join_type
         self.build_keys = node.build_keys
 
-    def validate(self):
-        pass
-
     def exec(self, *args, **kwargs) -> Iterator[Batch]:
-        try:
-            child_executor = self.children[0]
-            # build in memory hash table and pass to the probe phase
-            # Assumption the hash table fits in memory
-            # Todo: Implement a partition based hash join (grace hash join)
-            cumm_batches = [
-                batch for batch in child_executor.exec() if not batch.empty()
-            ]
-            cumm_batches = Batch.concat(cumm_batches)
-            hash_keys = [key.col_alias for key in self.build_keys]
-            cumm_batches.reassign_indices_to_hash(hash_keys)
-            yield cumm_batches
-        except Exception as e:
-            logger.error(e)
-            raise ExecutorError(e)
+        child_executor = self.children[0]
+        # build in memory hash table and pass to the probe phase
+        # Assumption the hash table fits in memory
+        # Todo: Implement a partition based hash join (grace hash join)
+        cumm_batches = [batch for batch in child_executor.exec() if not batch.empty()]
+        cumm_batches = Batch.concat(cumm_batches)
+        hash_keys = [key.col_alias for key in self.build_keys]
+        cumm_batches.reassign_indices_to_hash(hash_keys)
+        yield cumm_batches
