@@ -32,10 +32,7 @@ class LimitExecutor(AbstractExecutor):
         super().__init__(node)
         self._limit_count = node.limit_value
 
-    def validate(self):
-        pass
-
-    def exec(self) -> Iterator[Batch]:
+    def exec(self, *args, **kwargs) -> Iterator[Batch]:
         child_executor = self.children[0]
         remaining_tuples = self._limit_count
         # aggregates the batches into one large batch
