@@ -34,10 +34,7 @@ class PPExecutor(AbstractExecutor):
         super().__init__(node)
         self.predicate = node.predicate
 
-    def validate(self):
-        pass
-
-    def exec(self) -> Iterator[Batch]:
+    def exec(self, *args, **kwargs) -> Iterator[Batch]:
         child_executor = self.children[0]
         for batch in child_executor.exec():
             outcomes = self.predicate.evaluate(batch)
