@@ -125,6 +125,12 @@ class Batch:
             )
         )
 
+    @classmethod
+    def compare_like(cls, batch1: Batch, batch2: Batch) -> None:
+        col = batch1._frames.iloc[:, 0]
+        regex = batch2._frames.iloc[:, 0][0]
+        return cls(pd.DataFrame(col.astype("str").str.match(pat=regex)))
+
     def __str__(self) -> str:
         with pd.option_context(
             "display.pprint_nest_depth", 1, "display.max_colwidth", 100
@@ -132,6 +138,8 @@ class Batch:
             return f"{self._frames}"
 
     def __eq__(self, other: Batch):
+        # this function does not work if a column is a nested numpy arrays
+        # (eg, bboxes from yolo).
         return self._frames[sorted(self.columns)].equals(
             other.frames[sorted(other.columns)]
         )
@@ -165,22 +173,23 @@ class Batch:
         new_batch = Batch(new_frames)
         return new_batch
 
-    def apply_function_expression(self, expr: Callable) -> None:
+    def apply_function_expression(self, expr: Callable) -> Batch:
         """
         Execute function expression on frames.
         """
-        self._frames = expr(self._frames)
+        return Batch(expr(self._frames))
+
+    def iterrows(self):
+        return self._frames.iterrows()
 
     def sort(self, by=None) -> None:
         """
         in_place sort
         """
+        if self.empty():
+            return
         if by is None:
-            if not self.empty():
-                by = self.columns[0]
-            else:
-                logger.warn("Sorting an empty batch")
-                return
+            by = self.columns[0]
         self._frames.sort_values(by=by, ignore_index=True, inplace=True)
 
     def sort_orderby(self, by, sort_type=None) -> None:
@@ -196,21 +205,15 @@ class Batch:
         if sort_type is None:
             sort_type = [True]
 
-        if by is not None:
-            for column in by:
-                if column not in self._frames.columns:
-                    logger.error(
-                        "Can not orderby non-projected column: {}".format(column)
-                    )
-                    raise KeyError(
-                        "Can not orderby non-projected column: {}".format(column)
-                    )
+        assert by is not None
+        for column in by:
+            assert (
+                column in self._frames.columns
+            ), "Can not orderby non-projected column: {}".format(column)
 
-            self._frames.sort_values(
-                by, ascending=sort_type, ignore_index=True, inplace=True
-            )
-        else:
-            logger.warn("Columns and Sort Type are required for orderby")
+        self._frames.sort_values(
+            by, ascending=sort_type, ignore_index=True, inplace=True
+        )
 
     def invert(self) -> None:
         self._frames = ~self._frames
@@ -246,23 +249,9 @@ class Batch:
         cols = cols or []
         verfied_cols = [c for c in cols if c in self._frames]
         unknown_cols = list(set(cols) - set(verfied_cols))
-        if len(unknown_cols):
-            logger.warn(
-                "Unexpected columns %s\n\
-                                 Frames: %s"
-                % (unknown_cols, self._frames)
-            )
+        assert len(unknown_cols) == 0, unknown_cols
         return Batch(self._frames[verfied_cols])
 
-    def repeat(self, times: int) -> None:
-        """
-        Repeat the rows of a dataframe.
-
-        Arguments:
-            times: number of times to repeat
-        """
-        self._frames = pd.DataFrame(np.repeat(self._frames.to_numpy(), times, axis=0))
-
     @classmethod
     def merge_column_wise(cls, batches: List[Batch], auto_renaming=False) -> Batch:
         """
@@ -274,9 +263,9 @@ class Batch:
         Returns:
             Batch: Merged batch object
         """
-
         if not len(batches):
             return Batch()
+
         frames = [batch.frames for batch in batches]
         new_frames = pd.concat(frames, axis=1, copy=False, ignore_index=False).fillna(
             method="ffill"
@@ -421,7 +410,6 @@ class Batch:
                     f"Expected {len(alias.col_names)} columns {alias.col_names},"
                     f"got {len(self.columns)} columns {self.columns}."
                 )
-                logger.error(err_msg)
                 raise RuntimeError(err_msg)
             new_col_names = [
                 "{}.{}".format(alias.alias_name, col_name)
@@ -449,6 +437,9 @@ class Batch:
 
         self._frames.columns = new_col_names
 
+    def to_numpy(self):
+        return self._frames.to_numpy()
+
     def rename(self, columns) -> None:
         "Rename column names"
         self._frames.rename(columns=columns, inplace=True)
