@@ -22,18 +22,19 @@ class PlanOprType(Enum):
     STORAGE_PLAN = auto()
     PP_FILTER = auto()
     INSERT = auto()
+    DELETE = auto()
     CREATE = auto()
     RENAME = auto()
     DROP = auto()
     CREATE_UDF = auto()
     LOAD_DATA = auto()
-    UPLOAD = auto()
     UNION = auto()
     GROUP_BY = auto()
     ORDER_BY = auto()
     LIMIT = auto()
     SAMPLE = auto()
     FUNCTION_SCAN = auto()
+    NESTED_LOOP_JOIN = auto()
     HASH_JOIN = auto()
     LATERAL_JOIN = auto()
     HASH_BUILD = auto()
