@@ -12,13 +12,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
 from typing import Dict, Iterator
 
 import cv2
 
 from eva.readers.abstract_reader import AbstractReader
-from eva.utils.logging_manager import logger
 
 
 class CVImageReader(AbstractReader):
@@ -27,9 +25,5 @@ class CVImageReader(AbstractReader):
 
     def _read(self) -> Iterator[Dict]:
         frame = cv2.imread(str(self.file_url))
-        if frame is None:
-            err_msg = f"Failed to read image file {self.file_url}"
-            logger.exception(err_msg)
-            raise Exception(err_msg)
-        else:
-            yield {"data": frame}
+        assert frame is not None, f"Failed to read image file {self.file_url}"
+        yield {"data": frame}
