@@ -24,8 +24,6 @@ except ImportError:
     raise ImportError(
         f"torchvision>=0.14.0 is required to use MVITActionRecognition, found {torchvision.__version__}"
     )
-from eva.models.catalog.frame_info import FrameInfo
-from eva.models.catalog.properties import ColorSpace
 from eva.udfs.abstract.pytorch_abstract_udf import PytorchAbstractClassifierUDF
 
 
@@ -40,10 +38,6 @@ class MVITActionRecognition(PytorchAbstractClassifierUDF):
         self.preprocess = self.weights.transforms()
         self.model.eval()
 
-    @property
-    def input_format(self) -> FrameInfo:
-        return FrameInfo(-1, -1, 3, ColorSpace.RGB)
-
     @property
     def labels(self) -> np.array([str]):
         return np.array(self.weights.meta["categories"])
