@@ -49,7 +49,7 @@ DummyFeatureExtractor_udf_query = """CREATE UDF
 )
 
 ArrayCount_udf_query = """CREATE UDF
-            IF NOT EXISTS  Array_Count
+            IF NOT EXISTS  ArrayCount
             INPUT (Input_Array NDARRAY ANYTYPE, Search_Key ANYTYPE)
             OUTPUT (key_count INTEGER)
             TYPE NdarrayUDF
@@ -97,16 +97,6 @@ Unnest_udf_query = """CREATE UDF IF NOT EXISTS Unnest
     EVA_INSTALLATION_DIR, NDARRAY_DIR
 )
 
-Timestamp_udf_query = """CREATE UDF
-            IF NOT EXISTS  Timestamp
-            INPUT (seconds INTEGER)
-            OUTPUT (timestamp NDARRAY STR(8))
-            TYPE NdarrayUDF
-            IMPL "{}/udfs/{}/timestamp.py";
-        """.format(
-    EVA_INSTALLATION_DIR, NDARRAY_DIR
-)
-
 Fastrcnn_udf_query = """CREATE UDF IF NOT EXISTS FastRCNNObjectDetector
       INPUT  (Frame_Array NDARRAY UINT8(3, ANYDIM, ANYDIM))
       OUTPUT (labels NDARRAY STR(ANYDIM), bboxes NDARRAY FLOAT32(ANYDIM, 4),
@@ -177,10 +167,8 @@ def init_builtin_udfs(mode="debug"):
     queries = [
         Fastrcnn_udf_query,
         ArrayCount_udf_query,
-        Timestamp_udf_query,
         Crop_udf_query,
         Open_udf_query,
-        YoloV5_udf_query,
         Similarity_udf_query
         # Disabled because required packages (eg., easy_ocr might not be preinstalled)
         # face_detection_udf_query,
@@ -196,5 +184,8 @@ def init_builtin_udfs(mode="debug"):
         ]
     )
 
+    if mode != "minimal":
+        queries.extend([YoloV5_udf_query])
+
     for query in queries:
         execute_query_fetch_all(query)
