@@ -13,14 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import unittest
-from test.util import (
+from test.util import (  # file_remove,
     create_dummy_4d_batches,
     create_dummy_batches,
     create_sample_video,
     create_table,
     file_remove,
     get_logical_query_plan,
-    load_inbuilt_udfs,
+    load_udfs_for_testing,
 )
 
 import numpy as np
@@ -31,12 +31,13 @@ from eva.binder.binder_utils import BinderError
 from eva.catalog.catalog_manager import CatalogManager
 from eva.configuration.constants import EVA_ROOT_DIR
 from eva.models.storage.batch import Batch
-from eva.readers.opencv_reader import OpenCVReader
+from eva.readers.decord_reader import DecordReader
 from eva.server.command_handler import execute_query_fetch_all
 
 NUM_FRAMES = 10
 
 
+@pytest.mark.notparallel
 class SelectExecutorTest(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
@@ -47,7 +48,7 @@ class SelectExecutorTest(unittest.TestCase):
         ua_detrac = f"{EVA_ROOT_DIR}/data/ua_detrac/ua_detrac.mp4"
         load_query = f"LOAD VIDEO '{ua_detrac}' INTO DETRAC;"
         execute_query_fetch_all(load_query)
-        load_inbuilt_udfs()
+        load_udfs_for_testing()
         cls.table1 = create_table("table1", 100, 3)
         cls.table2 = create_table("table2", 500, 3)
         cls.table3 = create_table("table3", 1000, 3)
@@ -83,9 +84,7 @@ class SelectExecutorTest(unittest.TestCase):
         expected_rows = [
             {
                 "myvideo.id": i,
-                "myvideo.data": np.array(
-                    np.ones((2, 2, 3)) * float(i + 1) * 25, dtype=np.uint8
-                ),
+                "myvideo.data": np.array(np.ones((32, 32, 3)) * i, dtype=np.uint8),
             }
             for i in range(NUM_FRAMES)
         ]
@@ -153,7 +152,7 @@ class SelectExecutorTest(unittest.TestCase):
         select_query = "SELECT id, data FROM MNIST;"
         actual_batch = execute_query_fetch_all(select_query)
         actual_batch.sort("mnist.id")
-        video_reader = OpenCVReader("data/mnist/mnist.mp4", batch_mem_size=30000000)
+        video_reader = DecordReader("data/mnist/mnist.mp4")
         expected_batch = Batch(frames=pd.DataFrame())
         for batch in video_reader.read():
             batch.frames["name"] = "mnist.mp4"
@@ -162,6 +161,37 @@ class SelectExecutorTest(unittest.TestCase):
         expected_batch = expected_batch.project(["mnist.id", "mnist.data"])
         self.assertEqual(actual_batch, expected_batch)
 
+    def test_should_load_and_select_real_audio_in_table(self):
+        query = """LOAD VIDEO 'data/sample_videos/touchdown.mp4'
+                   INTO TOUCHDOWN;"""
+        execute_query_fetch_all(query)
+
+        select_query = "SELECT id, audio FROM TOUCHDOWN;"
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort("touchdown.id")
+        video_reader = DecordReader("data/sample_videos/touchdown.mp4", read_audio=True)
+        expected_batch = Batch(frames=pd.DataFrame())
+        for batch in video_reader.read():
+            batch.frames["name"] = "touchdown.mp4"
+            expected_batch += batch
+        expected_batch.modify_column_alias("touchdown")
+        expected_batch = expected_batch.project(["touchdown.id", "touchdown.audio"])
+        self.assertEqual(actual_batch, expected_batch)
+
+    def test_should_throw_error_when_both_audio_and_video_selected(self):
+        query = """LOAD VIDEO 'data/sample_videos/touchdown.mp4'
+                   INTO TOUCHDOWN1;"""
+        execute_query_fetch_all(query)
+
+        select_query = "SELECT id, audio, data FROM TOUCHDOWN1;"
+        try:
+            execute_query_fetch_all(select_query)
+            self.fail("Didn't raise AssertionError")
+        except AssertionError as e:
+            self.assertEquals(
+                "Cannot query over both audio and video streams", e.args[0]
+            )
+
     def test_select_and_where_video_in_table(self):
         select_query = "SELECT * FROM MyVideo WHERE id = 5;"
         actual_batch = execute_query_fetch_all(select_query)
@@ -170,15 +200,7 @@ class SelectExecutorTest(unittest.TestCase):
 
         select_query = "SELECT data FROM MyVideo WHERE id = 5;"
         actual_batch = execute_query_fetch_all(select_query)
-        expected_rows = [
-            {
-                "myvideo.data": np.array(
-                    np.ones((2, 2, 3)) * float(5 + 1) * 25, dtype=np.uint8
-                )
-            }
-        ]
-        expected_batch = Batch(frames=pd.DataFrame(expected_rows))
-        self.assertEqual(actual_batch, expected_batch)
+        self.assertEqual(actual_batch, expected_batch.project(["myvideo.data"]))
 
         select_query = "SELECT id, data FROM MyVideo WHERE id >= 2;"
         actual_batch = execute_query_fetch_all(select_query)
@@ -266,6 +288,28 @@ class SelectExecutorTest(unittest.TestCase):
         self.assertEqual(len(actual_batch), len(expected_batch[0]))
         self.assertEqual(actual_batch, expected_batch[0])
 
+    def test_select_and_iframe_sample(self):
+        select_query = "SELECT id FROM MyVideo SAMPLE IFRAMES 7 ORDER BY id;"
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+
+        expected_batch = list(create_dummy_batches(filters=range(0, NUM_FRAMES, 7)))
+        expected_batch[0] = expected_batch[0].project(["myvideo.id"])
+
+        self.assertEqual(len(actual_batch), len(expected_batch[0]))
+        self.assertEqual(actual_batch, expected_batch[0])
+
+    def test_select_and_iframe_sample_without_sampling_rate(self):
+        select_query = "SELECT id FROM MyVideo SAMPLE IFRAMES ORDER BY id;"
+        actual_batch = execute_query_fetch_all(select_query)
+        actual_batch.sort()
+
+        expected_batch = list(create_dummy_batches(filters=range(0, NUM_FRAMES, 1)))
+        expected_batch[0] = expected_batch[0].project(["myvideo.id"])
+
+        self.assertEqual(len(actual_batch), len(expected_batch[0]))
+        self.assertEqual(actual_batch, expected_batch[0])
+
     def test_select_and_groupby_first(self):
         # groupby and orderby together not tested because groupby
         # only applies to video data which is already sorted
@@ -531,7 +575,7 @@ class SelectExecutorTest(unittest.TestCase):
                   FROM MyVideo JOIN LATERAL
                     DummyMultiObjectDetector(data) AS T(a, b);
                 """
-        with self.assertRaises(BinderError) as cm:
+        with self.assertRaises(AssertionError) as cm:
             execute_query_fetch_all(query)
         self.assertEqual(str(cm.exception), "Expected 1 output columns for T, got 2.")
 
@@ -574,7 +618,7 @@ class SelectExecutorTest(unittest.TestCase):
 
     def test_hash_join_with_multiple_tables(self):
         select_query = """SELECT * FROM table1 JOIN table2
-                          ON table1.a0 = table2.a0 JOIN table3
+                          ON table2.a0 = table1.a0 JOIN table3
                           ON table3.a1 = table1.a1 WHERE table1.a2 > 50;"""
         actual_batch = execute_query_fetch_all(select_query)
         tmp = pd.merge(
@@ -604,4 +648,38 @@ class SelectExecutorTest(unittest.TestCase):
             "SELECT DummyMultiObjectDetector(data).labels FROM MyVideo"
         )
         signature = plan.target_list[0].signature()
-        self.assertEqual(signature, "DummyMultiObjectDetector(MyVideo.data)")
+        udf_id = (
+            CatalogManager()
+            .get_udf_catalog_entry_by_name("DummyMultiObjectDetector")
+            .row_id
+        )
+        table_entry = CatalogManager().get_table_catalog_entry("MyVideo")
+        col_id = CatalogManager().get_column_catalog_entry(table_entry, "data").row_id
+        self.assertEqual(
+            signature, f"DummyMultiObjectDetector[{udf_id}](MyVideo.data[{col_id}])"
+        )
+
+    def test_complex_logical_expressions(self):
+        query = """SELECT id FROM MyVideo
+            WHERE DummyObjectDetector(data).label = ['{}']  ORDER BY id;"""
+        persons = execute_query_fetch_all(query.format("person")).frames.to_numpy()
+        bicycles = execute_query_fetch_all(query.format("bicycle")).frames.to_numpy()
+        import numpy as np
+
+        self.assertTrue(len(np.intersect1d(persons, bicycles)) == 0)
+
+        query_or = """SELECT id FROM MyVideo \
+            WHERE DummyObjectDetector(data).label = ['person']
+                OR DummyObjectDetector(data).label = ['bicycle']
+            ORDER BY id;"""
+        actual = execute_query_fetch_all(query_or)
+        expected = execute_query_fetch_all("SELECT id FROM MyVideo ORDER BY id")
+        self.assertEqual(expected, actual)
+
+        query_and = """SELECT id FROM MyVideo \
+            WHERE DummyObjectDetector(data).label = ['person']
+                AND DummyObjectDetector(data).label = ['bicycle']
+            ORDER BY id;"""
+
+        expected = execute_query_fetch_all(query_and)
+        self.assertEqual(len(expected), 0)
